@@ -2,24 +2,28 @@
 
 bufaux.h
 
-Author: Tatu Ylonen <ylo@cs.hut.fi>
+Author: Tatu Ylonen <ylo@ssh.fi>
 
-Copyright (c) 1995 Tatu Ylonen <ylo@cs.hut.fi>, Espoo, Finland
-                   All rights reserved
+Copyright (c) 1995 Tatu Ylonen <ylo@ssh.fi>, Espoo, Finland
+Copyright (c) 1995-1999 SSH Communications Security Oy, Espoo, Finland
+                        All rights reserved
 
 Created: Wed Mar 29 02:18:23 1995 ylo
 
 */
 
 /*
- * $Id: bufaux.h,v 1.1.1.1 1996/02/18 21:38:11 ylo Exp $
+ * $Id: bufaux.h,v 1.2 1999/11/17 17:04:40 tri Exp $
  * $Log: bufaux.h,v $
- * Revision 1.1.1.1  1996/02/18  21:38:11  ylo
- * 	Imported ssh-1.2.13.
+ * Revision 1.2  1999/11/17 17:04:40  tri
+ * 	Fixed copyright notices.
+ *
+ * Revision 1.1.1.1  1996/02/18 21:38:11  ylo
+ *      Imported ssh-1.2.13.
  *
  * Revision 1.2  1995/07/13  01:18:07  ylo
- * 	Removed "Last modified" header.
- * 	Added cvs log.
+ *      Removed "Last modified" header.
+ *      Added cvs log.
  *
  * $Endlog$
  */
