@@ -2,10 +2,11 @@
 
 ssh-agent.c
 
-Author: Tatu Ylonen <ylo@cs.hut.fi>
+Author: Tatu Ylonen <ylo@ssh.fi>
 
-Copyright (c) 1995 Tatu Ylonen <ylo@cs.hut.fi>, Espoo, Finland
-                   All rights reserved
+Copyright (c) 1995 Tatu Ylonen <ylo@ssh.fi>, Espoo, Finland
+Copyright (c) 1995-1999 SSH Communications Security Oy, Espoo, Finland
+                        All rights reserved
 
 Created: Wed Mar 29 03:46:59 1995 ylo
 
@@ -14,51 +15,63 @@ The authentication agent program.
 */
 
 /*
- * $Id: ssh-agent.c,v 1.19 1998/01/02 06:21:42 kivinen Exp $
+ * $Id: ssh-agent.c,v 1.22 1999/11/17 17:04:56 tri Exp $
  * $Log: ssh-agent.c,v $
- * Revision 1.19  1998/01/02  06:21:42  kivinen
- * 	Added -k option. Renamed SSH_AUTHENCATION_SOCKET to
- * 	SSH_AUTH_SOCK.
+ * Revision 1.22  1999/11/17 17:04:56  tri
+ * 	Fixed copyright notices.
+ *
+ * Revision 1.21  1999/02/21 19:52:40  ylo
+ *      Intermediate commit of ssh1.2.27 stuff.
+ *      Main change is sprintf -> snprintf; however, there are also
+ *      many other changes.
+ *
+ * Revision 1.20  1999/01/26 17:40:34  tri
+ *      Ignore forwarding notice packets, that may be added
+ *      by ssh2 agent forwarding.
+ *
+ * Revision 1.19  1998/01/02 06:21:42  kivinen
+ *      Added -k option. Renamed SSH_AUTHENCATION_SOCKET to
+ *      SSH_AUTH_SOCK.
  *
  * Revision 1.18  1997/04/17 04:15:11  kivinen
- * 	Removed some extra variables. Removed some warnings.
- * 	Added check to socket closing that it is really opened.
- * 	Added xstrdups to putenv calls.
+ *      Removed some extra variables. Removed some warnings.
+ *      Added check to socket closing that it is really opened.
+ *      Added xstrdups to putenv calls.
  *
  * Revision 1.17  1997/04/05 21:58:15  kivinen
- * 	Fixed agent option parsing. Added -- option support, patch from
- * 	Charles M. Hannum <mycroft@gnu.ai.mit.edu>.
- * 	Added closing of agent socket in parent, patch from Charles M.
- * 	Hannum <mycroft@gnu.ai.mit.edu>.
- * 	Added check for existance of O_NOCTTY (patch from
- * 	KOJIMA Hajime <kjm@rins.ryukoku.ac.jp>).
- * 	Added setting of SSH_AGENT_PID when running command too.
+ *      Fixed agent option parsing. Added -- option support, patch from
+ *      Charles M. Hannum <mycroft@gnu.ai.mit.edu>.
+ *      Added closing of agent socket in parent, patch from Charles M.
+ *      Hannum <mycroft@gnu.ai.mit.edu>.
+ *      Added check for existance of O_NOCTTY (patch from
+ *      KOJIMA Hajime <kjm@rins.ryukoku.ac.jp>).
+ *      Added setting of SSH_AGENT_PID when running command too.
  *
  * Revision 1.16  1997/03/19 17:39:36  kivinen
- * 	Added -c (csh style shell) and -s (/bin/sh style shell)
- * 	options.
- * 	Fixed /bin/sh command syntax so it will print FOO=1; export
- * 	FOO; instead of export FOO=1, which some shells doesn't
- * 	understand.
+ *      Added -c (csh style shell) and -s (/bin/sh style shell)
+ *      options.
+ *      Fixed /bin/sh command syntax so it will print FOO=1; export
+ *      FOO; instead of export FOO=1, which some shells doesn't
+ *      understand.
  *
  * Revision 1.15  1996/11/24 08:27:33  kivinen
- * 	Added new mode for ssh-agent. If no command is given fork to
- * 	background and print commands that can be executed in users
- * 	shell that will set SSH_AUTHENTICATION_SOCKET and
- * 	SSH_AGENT_PID.
+ *      Added new mode for ssh-agent. If no command is given fork to
+ *      background and print commands that can be executed in users
+ *      shell that will set SSH_AUTHENTICATION_SOCKET and
+ *      SSH_AGENT_PID.
  *
  * Revision 1.14  1996/11/19 12:09:00  kivinen
- * 	Fixed check when directory needs to be created.
+ *      Fixed check when directory needs to be created.
  *
  * Revision 1.13  1996/10/29 22:43:55  kivinen
- * 	log -> log_msg. Removed unused sockaddr_in sin.
- * 	Do not define SSH_AUTHENTICATION_SOCKET environment variable
- * 	if the agent could not be started.
+ *      log -> log_msg. Removed unused sockaddr_in sin.
+ *      Do not define SSH_AUTHENTICATION_SOCKET environment variable
+ *      if the agent could not be started.
  *
  * Revision 1.12  1996/10/29 12:34:29  ttsalo
- * 	Agent's behaviour improved: socket is created and listened to
- * 	before forking, and if creation fails, parent still executes
- * 	the specified command (without forking the child).
+ *      Agent's behaviour improved: socket is created and listened to
+ *      before forking, and if creation fails, parent still executes
+ *      the specified command (without forking the child).
  *
  * Revision 1.11  1996/10/21 16:17:28  ttsalo
  *       Implemented direct socket handling in ssh-agent
@@ -67,55 +80,55 @@ The authentication agent program.
  *      Added global variable 'original_real_uid' and it's initialization
  *
  * Revision 1.9  1996/10/12 22:19:32  ttsalo
- * 	Return value of mkdir is now checked.
+ *      Return value of mkdir is now checked.
  *
  * Revision 1.8  1996/09/27 14:01:33  ttsalo
- * 	Use AF_UNIX_SIZE(sunaddr) instead of sizeof(sunaddr)
+ *      Use AF_UNIX_SIZE(sunaddr) instead of sizeof(sunaddr)
  *
  * Revision 1.7  1996/09/11 17:56:52  kivinen
- * 	Changed limit of messages from 256 kB to 30 kB.
- * 	Added check that getpwuid succeeds.
+ *      Changed limit of messages from 256 kB to 30 kB.
+ *      Added check that getpwuid succeeds.
  *
  * Revision 1.6  1996/09/04 12:41:51  ttsalo
- * 	Minor fixes
+ *      Minor fixes
  *
  * Revision 1.5  1996/08/29 14:51:26  ttsalo
- * 	Agent-socket directory handling implemented
+ *      Agent-socket directory handling implemented
  *
  * Revision 1.4  1996/08/21 20:43:55  ttsalo
- * 	Made ssh-agent use a different, more secure way of storing
- * 	it's initial socket.
+ *      Made ssh-agent use a different, more secure way of storing
+ *      it's initial socket.
  *
  * Revision 1.3  1996/05/28 12:44:52  ylo
- * 	Remove unix-domain socket if a killed by a signal.
+ *      Remove unix-domain socket if a killed by a signal.
  *
  * Revision 1.2  1996/04/26 00:24:47  ylo
- * 	Fixed memory leaks.
- * 	Fixed free -> xfree (xmalloced data).
+ *      Fixed memory leaks.
+ *      Fixed free -> xfree (xmalloced data).
  *
  * Revision 1.1.1.1  1996/02/18 21:38:12  ylo
- * 	Imported ssh-1.2.13.
+ *      Imported ssh-1.2.13.
  *
  * Revision 1.6  1995/09/21  17:13:31  ylo
- * 	Support AF_UNIX_SIZE.
+ *      Support AF_UNIX_SIZE.
  *
  * Revision 1.5  1995/08/29  22:25:22  ylo
- * 	Added compatibility support for various authentication
- * 	protocol versions.
- * 	Fixed bug in deleting identity.
- * 	Added remove_all.
- * 	New file descriptor code.
+ *      Added compatibility support for various authentication
+ *      protocol versions.
+ *      Fixed bug in deleting identity.
+ *      Added remove_all.
+ *      New file descriptor code.
  *
  * Revision 1.4  1995/08/21  23:27:31  ylo
- * 	Added support for session_id and response_type in
- * 	authentication requests.
+ *      Added support for session_id and response_type in
+ *      authentication requests.
  *
  * Revision 1.3  1995/07/26  23:29:13  ylo
- * 	Print software version with usage message.
+ *      Print software version with usage message.
  *
  * Revision 1.2  1995/07/13  01:38:26  ylo
- * 	Removed "Last modified" header.
- * 	Added cvs log.
+ *      Removed "Last modified" header.
+ *      Added cvs log.
  *
  * $Endlog$
  */
@@ -171,7 +184,7 @@ void process_request_identity(SocketEntry *e)
       buffer_put_mp_int(&msg, &identities[i].key.e);
       buffer_put_mp_int(&msg, &identities[i].key.n);
       buffer_put_string(&msg, identities[i].comment, 
-			strlen(identities[i].comment));
+                        strlen(identities[i].comment));
     }
   buffer_put_int(&e->output, buffer_len(&msg));
   buffer_append(&e->output, buffer_ptr(&msg), buffer_len(&msg));
@@ -209,49 +222,49 @@ void process_authentication_challenge(SocketEntry *e)
     }
   for (i = 0; i < num_identities; i++)
     if (pub_bits == identities[i].key.bits &&
-	mpz_cmp(&pub_e, &identities[i].key.e) == 0 &&
-	mpz_cmp(&pub_n, &identities[i].key.n) == 0)
+        mpz_cmp(&pub_e, &identities[i].key.e) == 0 &&
+        mpz_cmp(&pub_n, &identities[i].key.n) == 0)
       {
-	/* Decrypt the challenge using the private key. */
-	rsa_private_decrypt(&challenge, &challenge, &identities[i].key);
+        /* Decrypt the challenge using the private key. */
+        rsa_private_decrypt(&challenge, &challenge, &identities[i].key);
 
-	/* Compute the desired response. */
-	switch (response_type)
-	  {
-	  case 0: /* As of protocol 1.0 */
-	    /* This response type is no longer supported. */
-	    log_msg("Compatibility with ssh protocol 1.0 no longer supported.");
-	    buffer_put_char(&msg, SSH_AGENT_FAILURE);
-	    goto send;
+        /* Compute the desired response. */
+        switch (response_type)
+          {
+          case 0: /* As of protocol 1.0 */
+            /* This response type is no longer supported. */
+            log_msg("Compatibility with ssh protocol 1.0 no longer supported.");
+            buffer_put_char(&msg, SSH_AGENT_FAILURE);
+            goto send;
 
-	  case 1: /* As of protocol 1.1 */
-	    /* The response is MD5 of decrypted challenge plus session id. */
-	    mp_linearize_msb_first(buf, 32, &challenge);
-	    MD5Init(&md);
-	    MD5Update(&md, buf, 32);
-	    MD5Update(&md, session_id, 16);
-	    MD5Final(mdbuf, &md);
-	    break;
+          case 1: /* As of protocol 1.1 */
+            /* The response is MD5 of decrypted challenge plus session id. */
+            mp_linearize_msb_first(buf, 32, &challenge);
+            MD5Init(&md);
+            MD5Update(&md, buf, 32);
+            MD5Update(&md, session_id, 16);
+            MD5Final(mdbuf, &md);
+            break;
 
-	  default:
-	    fatal("process_authentication_challenge: bad response_type %d", 
-		  response_type);
-	    break;
-	  }
+          default:
+            fatal("process_authentication_challenge: bad response_type %d", 
+                  response_type);
+            break;
+          }
 
-	/* Send the response. */
-	buffer_put_char(&msg, SSH_AGENT_RSA_RESPONSE);
-	for (i = 0; i < 16; i++)
-	  buffer_put_char(&msg, mdbuf[i]);
+        /* Send the response. */
+        buffer_put_char(&msg, SSH_AGENT_RSA_RESPONSE);
+        for (i = 0; i < 16; i++)
+          buffer_put_char(&msg, mdbuf[i]);
 
-	goto send;
+        goto send;
       }
   /* Unknown identity.  Send failure. */
   buffer_put_char(&msg, SSH_AGENT_FAILURE);
  send:
   buffer_put_int(&e->output, buffer_len(&msg));
   buffer_append(&e->output, buffer_ptr(&msg),
-		buffer_len(&msg));
+                buffer_len(&msg));
   buffer_free(&msg);
   mpz_clear(&pub_e);
   mpz_clear(&pub_n);
@@ -276,23 +289,23 @@ void process_remove_identity(SocketEntry *e)
   for (i = 0; i < num_identities; i++)
     if (mpz_cmp(&identities[i].key.n, &n) == 0)
       {
-	/* We have this key.  Free the old key.  Since we don\'t want to leave
-	   empty slots in the middle of the array, we actually free the
-	   key there and copy data from the last entry. */
-	rsa_clear_private_key(&identities[i].key);
-	xfree(identities[i].comment);
-	if (i < num_identities - 1)
-	  identities[i] = identities[num_identities - 1];
-	num_identities--;
-	if (num_identities == 0)
-	  xfree(identities);
-	mpz_clear(&dummy);
-	mpz_clear(&n);
+        /* We have this key.  Free the old key.  Since we don\'t want to leave
+           empty slots in the middle of the array, we actually free the
+           key there and copy data from the last entry. */
+        rsa_clear_private_key(&identities[i].key);
+        xfree(identities[i].comment);
+        if (i < num_identities - 1)
+          identities[i] = identities[num_identities - 1];
+        num_identities--;
+        if (num_identities == 0)
+          xfree(identities);
+        mpz_clear(&dummy);
+        mpz_clear(&n);
 
-	/* Send success. */
-	buffer_put_int(&e->output, 1);
-	buffer_put_char(&e->output, SSH_AGENT_SUCCESS);
-	return;
+        /* Send success. */
+        buffer_put_int(&e->output, 1);
+        buffer_put_char(&e->output, SSH_AGENT_SUCCESS);
+        return;
       }
   /* We did not have the key. */
   mpz_clear(&dummy);
@@ -317,8 +330,9 @@ void process_remove_all_identities(SocketEntry *e)
     }
 
   /* Mark that there are no identities. */
+  if (num_identities != 0)
+    xfree(identities);
   num_identities = 0;
-  xfree(identities);
   
   /* Send success. */
   buffer_put_int(&e->output, 1);
@@ -357,15 +371,15 @@ void process_add_identity(SocketEntry *e)
   for (i = 0; i < num_identities; i++)
     if (mpz_cmp(&identities[i].key.n, &k->n) == 0)
       {
-	/* We already have this key.  Clear and free the new data and
-	   return success. */
-	rsa_clear_private_key(k);
-	xfree(identities[num_identities].comment);
+        /* We already have this key.  Clear and free the new data and
+           return success. */
+        rsa_clear_private_key(k);
+        xfree(identities[num_identities].comment);
 
-	/* Send success. */
-	buffer_put_int(&e->output, 1);
-	buffer_put_char(&e->output, SSH_AGENT_SUCCESS);
-	return;
+        /* Send success. */
+        buffer_put_int(&e->output, 1);
+        buffer_put_char(&e->output, SSH_AGENT_SUCCESS);
+        return;
       }
 
   /* Increment the number of identities. */
@@ -415,6 +429,9 @@ void process_message(SocketEntry *e)
     case SSH_AGENTC_REMOVE_ALL_RSA_IDENTITIES:
       process_remove_all_identities(e);
       break;
+    case 206: /* SSH_AGENT_FORWARDING_NOTICE */
+      /* This is a forwarding notice from ssh2.  Ignore this. */
+      break;
     default:
       /* Unknown message.  Respond with failure. */
       error("Unknown message %d", type);
@@ -442,11 +459,11 @@ void new_socket(int type, int fd)
   for (i = 0; i < sockets_alloc; i++)
     if (sockets[i].type == AUTH_UNUSED)
       {
-	sockets[i].fd = fd;
-	sockets[i].type = type;
-	buffer_init(&sockets[i].input);
-	buffer_init(&sockets[i].output);
-	return;
+        sockets[i].fd = fd;
+        sockets[i].type = type;
+        buffer_init(&sockets[i].input);
+        buffer_init(&sockets[i].output);
+        return;
       }
   old_alloc = sockets_alloc;
   sockets_alloc += 10;
@@ -470,15 +487,15 @@ void prepare_select(fd_set *readset, fd_set *writeset)
       {
       case AUTH_SOCKET_FD:
       case AUTH_SOCKET:
-	FD_SET(sockets[i].fd, readset);
-	if (buffer_len(&sockets[i].output) > 0)
-	  FD_SET(sockets[i].fd, writeset);
-	break;
+        FD_SET(sockets[i].fd, readset);
+        if (buffer_len(&sockets[i].output) > 0)
+          FD_SET(sockets[i].fd, writeset);
+        break;
       case AUTH_UNUSED:
-	break;
+        break;
       default:
-	fatal("Unknown socket type %d", sockets[i].type);
-	break;
+        fatal("Unknown socket type %d", sockets[i].type);
+        break;
       }
 }
 
@@ -493,55 +510,55 @@ void after_select(fd_set *readset, fd_set *writeset)
     switch (sockets[i].type)
       {
       case AUTH_UNUSED:
-	break;
+        break;
       case AUTH_SOCKET:
-	if (FD_ISSET(sockets[i].fd, readset))
-	  {
-	    len = AF_UNIX_SIZE(sunaddr);
-	    sock = accept(sockets[i].fd, (struct sockaddr *)&sunaddr, &len);
-	    if (sock < 0)
-	      {
-		perror("accept from AUTH_SOCKET");
-		break;
-	      }
-	    new_socket(AUTH_SOCKET_FD, sock);
-	  }
-	break;
+        if (FD_ISSET(sockets[i].fd, readset))
+          {
+            len = AF_UNIX_SIZE(sunaddr);
+            sock = accept(sockets[i].fd, (struct sockaddr *)&sunaddr, &len);
+            if (sock < 0)
+              {
+                perror("accept from AUTH_SOCKET");
+                break;
+              }
+            new_socket(AUTH_SOCKET_FD, sock);
+          }
+        break;
       case AUTH_SOCKET_FD:
-	if (buffer_len(&sockets[i].output) > 0 &&
-	    FD_ISSET(sockets[i].fd, writeset))
-	  {
-	    len = write(sockets[i].fd, buffer_ptr(&sockets[i].output),
-			buffer_len(&sockets[i].output));
-	    if (len <= 0)
-	      {
-		shutdown(sockets[i].fd, 2);
-		close(sockets[i].fd);
-		sockets[i].type = AUTH_UNUSED;
-		buffer_free(&sockets[i].input);
-		buffer_free(&sockets[i].output);
-		break;
-	      }
-	    buffer_consume(&sockets[i].output, len);
-	  }
-	if (FD_ISSET(sockets[i].fd, readset))
-	  {
-	    len = read(sockets[i].fd, buf, sizeof(buf));
-	    if (len <= 0)
-	      {
-		shutdown(sockets[i].fd, 2);
-		close(sockets[i].fd);
-		sockets[i].type = AUTH_UNUSED;
-		buffer_free(&sockets[i].input);
-		buffer_free(&sockets[i].output);
-		break;
-	      }
-	    buffer_append(&sockets[i].input, buf, len);
-	    process_message(&sockets[i]);
-	  }
-	break;
+        if (buffer_len(&sockets[i].output) > 0 &&
+            FD_ISSET(sockets[i].fd, writeset))
+          {
+            len = write(sockets[i].fd, buffer_ptr(&sockets[i].output),
+                        buffer_len(&sockets[i].output));
+            if (len <= 0)
+              {
+                shutdown(sockets[i].fd, 2);
+                close(sockets[i].fd);
+                sockets[i].type = AUTH_UNUSED;
+                buffer_free(&sockets[i].input);
+                buffer_free(&sockets[i].output);
+                break;
+              }
+            buffer_consume(&sockets[i].output, len);
+          }
+        if (FD_ISSET(sockets[i].fd, readset))
+          {
+            len = read(sockets[i].fd, buf, sizeof(buf));
+            if (len <= 0)
+              {
+                shutdown(sockets[i].fd, 2);
+                close(sockets[i].fd);
+                sockets[i].type = AUTH_UNUSED;
+                buffer_free(&sockets[i].input);
+                buffer_free(&sockets[i].output);
+                break;
+              }
+            buffer_append(&sockets[i].input, buf, len);
+            process_message(&sockets[i]);
+          }
+        break;
       default:
-	fatal("Unknown type %d", sockets[i].type);
+        fatal("Unknown type %d", sockets[i].type);
       }
 }
 
@@ -593,28 +610,28 @@ int main(int ac, char **av)
   while (ac > 1)
     {
       if (av[1][0] == '-')
-	{
-	  if (av[1][1] == '-' && av[1][2] == '\0')
-	    {
-	      av++;
-	      ac--;
-	      break;
-	    }
-	  for(i = 1; av[1][i] != '\0'; i++)
-	    {
-	      switch (av[1][i])
-		{
-		case 's': binsh = 1; break;
-		case 'c': binsh = 0; break;
-		case 'k': do_kill = 1; break;
-		default: erflg++; break;
-		}
-	    }
-	  av++;
-	  ac--;
-	}
+        {
+          if (av[1][1] == '-' && av[1][2] == '\0')
+            {
+              av++;
+              ac--;
+              break;
+            }
+          for(i = 1; av[1][i] != '\0'; i++)
+            {
+              switch (av[1][i])
+                {
+                case 's': binsh = 1; break;
+                case 'c': binsh = 0; break;
+                case 'k': do_kill = 1; break;
+                default: erflg++; break;
+                }
+            }
+          av++;
+          ac--;
+        }
       else
-	break;
+        break;
     }
   if (erflg)
     {
@@ -627,44 +644,44 @@ int main(int ac, char **av)
   if (do_kill)
     {
       if (getenv("SSH_AGENT_PID") == NULL)
-	{
-	  fprintf(stderr, "No SSH_AGENT_PID environment variable found\n");
-	  exit(1);
-	}
+        {
+          fprintf(stderr, "No SSH_AGENT_PID environment variable found\n");
+          exit(1);
+        }
       pid = atoi(getenv("SSH_AGENT_PID"));
       if (pid == 0)
-	{
-	  fprintf(stderr, "Invalid SSH_AGENT_PID value: %s\n",
-		  getenv("SSH_AGENT_PID"));
-	  exit(1);
-	}
+        {
+          fprintf(stderr, "Invalid SSH_AGENT_PID value: %s\n",
+                  getenv("SSH_AGENT_PID"));
+          exit(1);
+        }
       if (kill(pid, SIGTERM) != 0)
-	{
-	  fprintf(stderr, "Kill failed, either no agent process or permission denied\n");
-	  exit(1);
-	}
+        {
+          fprintf(stderr, "Kill failed, either no agent process or permission denied\n");
+          exit(1);
+        }
       if (getenv(SSH_AUTHSOCKET_ENV_NAME) == NULL)
-	{
-	  fprintf(stderr, "No %s environment variable found\n",
-		  SSH_AUTHSOCKET_ENV_NAME);
-	}
+        {
+          fprintf(stderr, "No %s environment variable found\n",
+                  SSH_AUTHSOCKET_ENV_NAME);
+        }
       else
-	{
-	  if (!binsh)		/* shell is *csh */
-	    printf("unsetenv %s;\n", SSH_AUTHSOCKET_ENV_NAME);
-	  else
-	      printf("unset %s;\n", SSH_AUTHSOCKET_ENV_NAME);
-	}
+        {
+          if (!binsh)           /* shell is *csh */
+            printf("unsetenv %s;\n", SSH_AUTHSOCKET_ENV_NAME);
+          else
+              printf("unset %s;\n", SSH_AUTHSOCKET_ENV_NAME);
+        }
       if (!binsh)
-	{			/* shell is *csh */
-	  printf("unsetenv SSH_AGENT_PID;\n");
-	  printf("echo Agent pid %d killed;\n", pid);
-	}
+        {                       /* shell is *csh */
+          printf("unsetenv SSH_AGENT_PID;\n");
+          printf("echo Agent pid %d killed;\n", pid);
+        }
       else
-	{
-	  printf("unset SSH_AGENT_PID;\n");
-	  printf("echo Agent pid %d killed;\n", pid);
-	}
+        {
+          printf("unset SSH_AGENT_PID;\n");
+          printf("echo Agent pid %d killed;\n", pid);
+        }
       exit(0);
     }
   
@@ -678,7 +695,8 @@ int main(int ac, char **av)
       exit(1);
     }
   
-  sprintf(socket_dir_name, SSH_AGENT_SOCKET_DIR, pw->pw_name);
+  snprintf(socket_dir_name, sizeof(socket_dir_name),
+           SSH_AGENT_SOCKET_DIR, pw->pw_name);
 
   /* Start setting up the socket. Do it before forking to guarantee
      that the socket exists when the parent starts executing the
@@ -705,21 +723,21 @@ int main(int ac, char **av)
       (st.st_mode & 077) != 0)
     {
       fprintf(stderr, "Bad modes or owner for directory \'%s\'\n",
-	      socket_dir_name);
+              socket_dir_name);
       goto fail_socket_setup;
     }
 
-  sprintf(socket_name,
-	  SSH_AGENT_SOCKET_DIR"/"SSH_AGENT_SOCKET,
-	  pw->pw_name, (int)getpid());
+  snprintf(socket_name, sizeof(socket_name),
+           SSH_AGENT_SOCKET_DIR"/"SSH_AGENT_SOCKET,
+           pw->pw_name, (int)getpid());
 
   /* Check that socket doesn't exist */
   ret = stat(socket_name, &st);
   if (ret != -1 && errno != ENOENT)
     {
       fprintf(stderr,
-	      "\'%s\' already exists (ssh-agent already running?)\n",
-	      socket_name);
+              "\'%s\' already exists (ssh-agent already running?)\n",
+              socket_name);
       goto fail_socket_setup;
     }
   sock = socket(AF_UNIX, SOCK_STREAM, 0);
@@ -760,47 +778,48 @@ fail_socket_setup:
   if (!creation_failed)
     pid = fork();
   else
-    pid = 1;			/* Run only parent code */
+    pid = 1;                    /* Run only parent code */
   if (pid != 0)
     {
       /* Parent - execute the given command, if given command. */
 
       /* Close the agent socket */
       if (sock != -1)
-	close(sock);
+        close(sock);
       
       if (ac == 1)
-	{			/* No command given print socket name */
-	  if (creation_failed)
-	    {
-	      printf("echo Agent creation failed, no agent started\n");
-	      exit(0);
-	    }
-	  
-	  if (!binsh)
-	    {			/* shell is *csh */
-	      printf("setenv %s %s;\n", SSH_AUTHSOCKET_ENV_NAME,
-		     socket_name);
-	      printf("setenv SSH_AGENT_PID %d;\n", pid);
-	      printf("echo Agent pid %d;\n", pid);
-	    }
-	  else
-	    {
-	      printf("%s=%s; export %s;\n", SSH_AUTHSOCKET_ENV_NAME,
-		     socket_name, SSH_AUTHSOCKET_ENV_NAME);
-	      printf("SSH_AGENT_PID=%d; export SSH_AGENT_PID;\n", pid);
-	      printf("echo Agent pid %d;\n", pid);
-	    }
-	  exit(0);
-	}
+        {                       /* No command given print socket name */
+          if (creation_failed)
+            {
+              printf("echo Agent creation failed, no agent started\n");
+              exit(0);
+            }
+          
+          if (!binsh)
+            {                   /* shell is *csh */
+              printf("setenv %s %s;\n", SSH_AUTHSOCKET_ENV_NAME,
+                     socket_name);
+              printf("setenv SSH_AGENT_PID %d;\n", pid);
+              printf("echo Agent pid %d;\n", pid);
+            }
+          else
+            {
+              printf("%s=%s; export %s;\n", SSH_AUTHSOCKET_ENV_NAME,
+                     socket_name, SSH_AUTHSOCKET_ENV_NAME);
+              printf("SSH_AGENT_PID=%d; export SSH_AGENT_PID;\n", pid);
+              printf("echo Agent pid %d;\n", pid);
+            }
+          exit(0);
+        }
       /* Command given run it */
       if (!creation_failed)
-	{
-	  sprintf(buf, "%s=%s", SSH_AUTHSOCKET_ENV_NAME, socket_name);
-	  putenv(xstrdup(buf));
-	  sprintf(buf, "SSH_AGENT_PID=%d", pid);
-	  putenv(xstrdup(buf));
-	}
+        {
+          snprintf(buf, sizeof(buf),
+                   "%s=%s", SSH_AUTHSOCKET_ENV_NAME, socket_name);
+          putenv(xstrdup(buf));
+          snprintf(buf, sizeof(buf), "SSH_AGENT_PID=%d", pid);
+          putenv(xstrdup(buf));
+        }
       execvp(av[1], av + 1);
       perror(av[1]);
       exit(1);
@@ -822,8 +841,8 @@ fail_socket_setup:
 #endif
     if (fd >= 0)
       {
-	(void)ioctl(fd, TIOCNOTTY, NULL);
-	close(fd);
+        (void)ioctl(fd, TIOCNOTTY, NULL);
+        close(fd);
       }
   }
 #endif /* TIOCNOTTY */
@@ -853,12 +872,12 @@ fail_socket_setup:
       FD_ZERO(&writeset);
       prepare_select(&readset, &writeset);
       if (select(max_fd + 1, &readset, &writeset, NULL, NULL) < 0)
-	{
-	  if (errno == EINTR)
-	    continue;
-	  perror("select");
-	  exit(1);
-	}
+        {
+          if (errno == EINTR)
+            continue;
+          perror("select");
+          exit(1);
+        }
       after_select(&readset, &writeset);
     }
   /*NOTREACHED*/
