@@ -2,10 +2,11 @@
 
 xmalloc.c
 
-Author: Tatu Ylonen <ylo@cs.hut.fi>
+Author: Tatu Ylonen <ylo@ssh.fi>
 
-Copyright (c) 1995 Tatu Ylonen <ylo@cs.hut.fi>, Espoo, Finland
-                   All rights reserved
+Copyright (c) 1995 Tatu Ylonen <ylo@ssh.fi>, Espoo, Finland
+Copyright (c) 1995-1999 SSH Communications Security Oy, Espoo, Finland
+                        All rights reserved
 
 Created: Mon Mar 20 21:23:10 1995 ylo
 
@@ -15,17 +16,20 @@ failure (they call fatal if they encounter an error).
 */
 
 /*
- * $Id: xmalloc.c,v 1.1.1.1 1996/02/18 21:38:11 ylo Exp $
+ * $Id: xmalloc.c,v 1.2 1999/11/17 17:05:01 tri Exp $
  * $Log: xmalloc.c,v $
- * Revision 1.1.1.1  1996/02/18  21:38:11  ylo
- * 	Imported ssh-1.2.13.
+ * Revision 1.2  1999/11/17 17:05:01  tri
+ * 	Fixed copyright notices.
+ *
+ * Revision 1.1.1.1  1996/02/18 21:38:11  ylo
+ *      Imported ssh-1.2.13.
  *
  * Revision 1.3  1995/08/29  22:36:39  ylo
- * 	Commented out malloc prototypes.
+ *      Commented out malloc prototypes.
  *
  * Revision 1.2  1995/07/13  01:41:33  ylo
- * 	Removed "Last modified" header.
- * 	Added cvs log.
+ *      Removed "Last modified" header.
+ *      Added cvs log.
  *
  * $Endlog$
  */
